@@ -130,6 +130,13 @@ class SharedDataFeeder():
             ds.loc[tag,'create_map'] = d1.tags[tag].create_map
             ds.loc[tag,'init_time'] = d1.tags[tag].init_time
             ds.loc[tag,'last_update'] = d1.tags[tag].last_update
-            ds.loc[tag,'first_update'] = d1.tags[tag].first_update
+            ds.loc[tag,'first_update'] = d1.tags[tag].first_update            
+            ds.loc[tag,'data_size'] = ds.loc[tag,'notnull_sum']*8/1000000
+            ds.loc[tag,'memory_size'] = d1[tag].memory_usage(deep=True).sum()/1000000
+            ds.loc[tag,'download_time'] = d1.tags[tag].download_time
+            ds.loc[tag,'download_speed'] = np.nan
+            if not pd.isnull(ds.loc[tag,'download_time']):
+                ds.loc[tag,'download_speed'] = ds.loc[tag,'data_size']/1000000/d1.tags[tag].download_time
+
 
         self.dataset_metadata.static = ds.reset_index()
