@@ -32,6 +32,7 @@ class SharedDataTimeSeries:
 
         self.create_map = 'na'
         self.init_time = time.time()
+        self.download_time = pd.NaT
         self.last_update = pd.NaT
         self.first_update = pd.NaT
         
@@ -77,7 +78,9 @@ class SharedDataTimeSeries:
                 if self.sharedData.s3read:
                     path, shm_name = self.getDataPath()
                     path = str(path)
+                    self.download_time = time.time()
                     S3SyncDownloadTimeSeries(path, shm_name)
+                    self.download_time = time.time()-self.download_time
                                         
                 self.Read()
         
